/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fa extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "\u060b" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "$CA" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNY", "\u00a5CN" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HKD", "$HK" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "\u0631\u06cc\u0627\u0644" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "$MX" },
            { "MXP", "MXP" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "NZD", "$NZ" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XCD", "$EC" },
            { "XOF", "\u0641\u0631\u0627\u0646\u06a9\u202fCFA" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "\u067e\u0632\u062a\u0627\u06cc \u0622\u0646\u062f\u0648\u0631\u0627" },
            { "aed", "\u062f\u0631\u0647\u0645 \u0627\u0645\u0627\u0631\u0627\u062a \u0645\u062a\u062d\u062f\u0647\u0654 \u0639\u0631\u0628\u06cc" },
            { "afa", "\u0627\u0641\u063a\u0627\u0646\u06cc \u0627\u0641\u063a\u0627\u0646\u0633\u062a\u0627\u0646 (\u06f1\u06f9\u06f2\u06f7 \u062a\u0627 \u06f2\u06f0\u06f0\u06f2)" },
            { "afn", "\u0627\u0641\u063a\u0627\u0646\u06cc \u0627\u0641\u063a\u0627\u0646\u0633\u062a\u0627\u0646" },
            { "alk", "\u0644\u06a9 \u0622\u0644\u0628\u0627\u0646\u06cc (\u06f1\u06f9\u06f4\u06f6 \u062a\u0627 \u06f1\u06f9\u06f6\u06f5)" },
            { "all", "\u0644\u06a9 \u0622\u0644\u0628\u0627\u0646\u06cc" },
            { "amd", "\u062f\u0631\u0627\u0645 \u0627\u0631\u0645\u0646\u0633\u062a\u0627\u0646" },
            { "ang", "\u06af\u06cc\u0644\u062f\u0631 \u0622\u0646\u062a\u06cc\u0644 \u0647\u0644\u0646\u062f" },
            { "aoa", "\u06a9\u0648\u0627\u0646\u0632\u0627\u06cc \u0622\u0646\u06af\u0648\u0644\u0627" },
            { "arm", "\u067e\u0632\u0648\u06cc \u0622\u0631\u0698\u0627\u0646\u062a\u06cc\u0646 (\u06f1\u06f8\u06f8\u06f1 \u062a\u0627 \u06f1\u06f9\u06f7\u06f0)" },
            { "arp", "\u067e\u0632\u0648\u06cc \u0622\u0631\u0698\u0627\u0646\u062a\u06cc\u0646 (\u06f1\u06f9\u06f8\u06f3 \u062a\u0627 \u06f1\u06f9\u06f8\u06f5)\u200f" },
            { "ars", "\u067e\u0632\u0648\u06cc \u0622\u0631\u0698\u0627\u0646\u062a\u06cc\u0646" },
            { "ats", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0627\u062a\u0631\u06cc\u0634" },
            { "aud", "\u062f\u0644\u0627\u0631 \u0627\u0633\u062a\u0631\u0627\u0644\u06cc\u0627" },
            { "awg", "\u0641\u0644\u0648\u0631\u06cc\u0646 \u0622\u0631\u0648\u0628\u0627" },
            { "azm", "\u0645\u0646\u0627\u062a \u062c\u0645\u0647\u0648\u0631\u06cc \u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646 (\u06f1\u06f9\u06f9\u06f3 \u062a\u0627 \u06f2\u06f0\u06f0\u06f6)" },
            { "azn", "\u0645\u0646\u0627\u062a \u062c\u0645\u0647\u0648\u0631\u06cc \u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646" },
            { "bad", "\u062f\u06cc\u0646\u0627\u0631 \u0628\u0648\u0633\u0646\u06cc \u0648 \u0647\u0631\u0632\u06af\u0648\u06cc\u0646 (\u06f1\u06f9\u06f9\u06f2 \u062a\u0627 \u06f1\u06f9\u06f9\u06f4)" },
            { "bam", "\u0645\u0627\u0631\u06a9 \u062a\u0628\u062f\u06cc\u0644\u200c\u067e\u0630\u06cc\u0631 \u0628\u0648\u0633\u0646\u06cc \u0648 \u0647\u0631\u0632\u06af\u0648\u06cc\u0646" },
            { "bbd", "\u062f\u0644\u0627\u0631 \u0628\u0627\u0631\u0628\u0627\u062f\u0648\u0633" },
            { "bdt", "\u062a\u0627\u06a9\u0627\u06cc \u0628\u0646\u06af\u0644\u0627\u062f\u0634" },
            { "bef", "\u0641\u0631\u0627\u0646\u06a9 \u0628\u0644\u0698\u06cc\u06a9" },
            { "bel", "\u0641\u0631\u0627\u0646\u06a9 \u0628\u0644\u0698\u06cc\u06a9 (\u0645\u0627\u0644\u06cc)" },
            { "bgn", "\u0644\u0641 \u0628\u0644\u063a\u0627\u0631\u0633\u062a\u0627\u0646" },
            { "bhd", "\u062f\u06cc\u0646\u0627\u0631 \u0628\u062d\u0631\u06cc\u0646" },
            { "bif", "\u0641\u0631\u0627\u0646\u06a9 \u0628\u0648\u0631\u0648\u0646\u062f\u06cc" },
            { "bmd", "\u062f\u0644\u0627\u0631 \u0628\u0631\u0645\u0648\u062f\u0627" },
            { "bnd", "\u062f\u0644\u0627\u0631 \u0628\u0631\u0648\u0646\u0626\u06cc" },
            { "bob", "\u0628\u0648\u0644\u06cc\u0648\u06cc\u0627\u0646\u0648\u06cc \u0628\u0648\u0644\u06cc\u0648\u06cc" },
            { "bop", "\u067e\u0632\u0648\u06cc \u0628\u0648\u0644\u06cc\u0648\u06cc" },
            { "brl", "\u0631\u0626\u0627\u0644 \u0628\u0631\u0632\u06cc\u0644" },
            { "bsd", "\u062f\u0644\u0627\u0631 \u0628\u0627\u0647\u0627\u0645\u0627" },
            { "btn", "\u0627\u0646\u06af\u0648\u0644\u062a\u0631\u0648\u0645 \u0628\u0648\u062a\u0627\u0646" },
            { "bwp", "\u067e\u0648\u0644\u0627\u06cc \u0628\u0648\u062a\u0633\u0648\u0627\u0646\u0627" },
            { "byb", "\u0631\u0648\u0628\u0644 \u062c\u062f\u06cc\u062f \u0628\u0644\u0627\u0631\u0648\u0633 (\u06f1\u06f9\u06f9\u06f4 \u062a\u0627 \u06f1\u06f9\u06f9\u06f9)" },
            { "byn", "\u0631\u0648\u0628\u0644 \u0628\u0644\u0627\u0631\u0648\u0633" },
            { "byr", "\u0631\u0648\u0628\u0644 \u0628\u0644\u0627\u0631\u0648\u0633\u06cc (\u06f2\u06f0\u06f1\u06f6\u2013\u06f2\u06f0\u06f0\u06f0)" },
            { "bzd", "\u062f\u0644\u0627\u0631 \u0628\u0644\u06cc\u0632" },
            { "cad", "\u062f\u0644\u0627\u0631 \u06a9\u0627\u0646\u0627\u062f\u0627" },
            { "cdf", "\u0641\u0631\u0627\u0646\u06a9 \u06a9\u0646\u06af\u0648" },
            { "chf", "\u0641\u0631\u0627\u0646\u06a9 \u0633\u0648\u0626\u06cc\u0633" },
            { "clp", "\u067e\u0632\u0648\u06cc \u0634\u06cc\u0644\u06cc" },
            { "cnh", "\u06cc\u0648\u0622\u0646 \u0686\u06cc\u0646 (\u0628\u0631\u0648\u0646\u200c\u0645\u0631\u0632\u06cc)" },
            { "cny", "\u06cc\u0648\u0622\u0646 \u0686\u06cc\u0646" },
            { "cop", "\u067e\u0632\u0648\u06cc \u06a9\u0644\u0645\u0628\u06cc\u0627" },
            { "crc", "\u06a9\u0648\u0644\u0648\u0646 \u06a9\u0627\u0633\u062a\u0627\u0631\u06cc\u06a9\u0627" },
            { "csd", "\u062f\u06cc\u0646\u0627\u0631 \u0635\u0631\u0628\u0633\u062a\u0627\u0646 (\u06f2\u06f0\u06f0\u06f2 \u062a\u0627 \u06f2\u06f0\u06f0\u06f6)" },
            { "cuc", "\u067e\u0632\u0648\u06cc \u062a\u0628\u062f\u06cc\u0644\u200c\u067e\u0630\u06cc\u0631 \u06a9\u0648\u0628\u0627" },
            { "cup", "\u067e\u0632\u0648\u06cc \u06a9\u0648\u0628\u0627" },
            { "cve", "\u0627\u0633\u06a9\u0648\u062f\u0648\u06cc \u06a9\u06cc\u067e\u200c\u0648\u0631\u062f" },
            { "cyp", "\u067e\u0648\u0646\u062f \u0642\u0628\u0631\u0633" },
            { "czk", "\u06a9\u0648\u0631\u0648\u0646\u0627\u06cc \u062c\u0645\u0647\u0648\u0631\u06cc \u0686\u06a9" },
            { "ddm", "\u0645\u0627\u0631\u06a9 \u0622\u0644\u0645\u0627\u0646 \u0634\u0631\u0642\u06cc" },
            { "dem", "\u0645\u0627\u0631\u06a9 \u0622\u0644\u0645\u0627\u0646" },
            { "djf", "\u0641\u0631\u0627\u0646\u06a9 \u062c\u06cc\u0628\u0648\u062a\u06cc" },
            { "dkk", "\u06a9\u0631\u0648\u0646 \u062f\u0627\u0646\u0645\u0627\u0631\u06a9" },
            { "dop", "\u067e\u0632\u0648\u06cc \u062c\u0645\u0647\u0648\u0631\u06cc \u062f\u0648\u0645\u06cc\u0646\u06cc\u06a9\u0646" },
            { "dzd", "\u062f\u06cc\u0646\u0627\u0631 \u0627\u0644\u062c\u0632\u0627\u06cc\u0631" },
            { "eek", "\u06a9\u0631\u0648\u0646 \u0627\u0633\u062a\u0648\u0646\u06cc" },
            { "egp", "\u067e\u0648\u0646\u062f \u0645\u0635\u0631" },
            { "ern", "\u0646\u0627\u06a9\u0641\u0627\u06cc \u0627\u0631\u06cc\u062a\u0631\u0647" },
            { "esp", "\u067e\u0632\u062a\u0627\u06cc \u0627\u0633\u067e\u0627\u0646\u06cc\u0627" },
            { "etb", "\u0628\u06cc\u0631 \u0627\u062a\u06cc\u0648\u067e\u06cc" },
            { "eur", "\u06cc\u0648\u0631\u0648" },
            { "fjd", "\u062f\u0644\u0627\u0631 \u0641\u06cc\u062c\u06cc" },
            { "fkp", "\u067e\u0648\u0646\u062f \u062c\u0632\u0627\u06cc\u0631 \u0641\u0627\u0644\u06a9\u0644\u0646\u062f" },
            { "frf", "\u0641\u0631\u0627\u0646\u06a9 \u0641\u0631\u0627\u0646\u0633\u0647" },
            { "gbp", "\u067e\u0648\u0646\u062f \u0628\u0631\u06cc\u062a\u0627\u0646\u06cc\u0627" },
            { "gel", "\u0644\u0627\u0631\u06cc \u06af\u0631\u062c\u0633\u062a\u0627\u0646" },
            { "ghs", "\u0633\u062f\u06cc \u063a\u0646\u0627" },
            { "gip", "\u067e\u0648\u0646\u062f \u062c\u0628\u0644\u200c\u0627\u0644\u0637\u0627\u0631\u0642" },
            { "gmd", "\u062f\u0627\u0644\u0627\u0633\u06cc \u06af\u0627\u0645\u0628\u06cc\u0627" },
            { "gnf", "\u0641\u0631\u0627\u0646\u06a9 \u06af\u06cc\u0646\u0647" },
            { "grd", "\u062f\u0631\u0627\u062e\u0645\u0627\u06cc \u06cc\u0648\u0646\u0627\u0646" },
            { "gtq", "\u06a9\u062a\u0632\u0627\u0644 \u06af\u0648\u0627\u062a\u0645\u0627\u0644\u0627" },
            { "gwp", "\u067e\u0632\u0648\u06cc \u06af\u06cc\u0646\u0647\u0654 \u0628\u06cc\u0633\u0627\u0626\u0648" },
            { "gyd", "\u062f\u0644\u0627\u0631 \u06af\u0648\u06cc\u0627\u0646\u0627" },
            { "hkd", "\u062f\u0644\u0627\u0631 \u0647\u0646\u06af\u200c\u06a9\u0646\u06af" },
            { "hnl", "\u0644\u0645\u067e\u06cc\u0631\u0627\u06cc \u0647\u0646\u062f\u0648\u0631\u0627\u0633" },
            { "hrd", "\u062f\u06cc\u0646\u0627\u0631 \u06a9\u0631\u0648\u0627\u0633\u06cc" },
            { "hrk", "\u06a9\u0648\u0646\u0627\u06cc \u06a9\u0631\u0648\u0627\u0633\u06cc" },
            { "htg", "\u06af\u0648\u0631\u062f \u0647\u0627\u0626\u06cc\u062a\u06cc" },
            { "huf", "\u0641\u0648\u0631\u06cc\u0646\u062a \u0645\u062c\u0627\u0631\u0633\u062a\u0627\u0646" },
            { "idr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0627\u0646\u062f\u0648\u0646\u0632\u06cc" },
            { "iep", "\u067e\u0648\u0646\u062f \u0627\u06cc\u0631\u0644\u0646\u062f" },
            { "ilp", "\u067e\u0648\u0646\u062f \u0627\u0633\u0631\u0627\u0626\u06cc\u0644" },
            { "ilr", "\u0634\u0642\u0644 \u0627\u0633\u0631\u0627\u0626\u06cc\u0644 (\u06f1\u06f9\u06f8\u06f0 \u062a\u0627 \u06f1\u06f9\u06f8\u06f5)" },
            { "ils", "\u0634\u0642\u0644 \u062c\u062f\u06cc\u062f \u0627\u0633\u0631\u0627\u0626\u06cc\u0644" },
            { "inr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0647\u0646\u062f" },
            { "iqd", "\u062f\u06cc\u0646\u0627\u0631 \u0639\u0631\u0627\u0642" },
            { "irr", "\u0631\u06cc\u0627\u0644 \u0627\u06cc\u0631\u0627\u0646" },
            { "isj", "\u06a9\u0631\u0648\u0646\u0627\u06cc \u0627\u06cc\u0633\u0644\u0646\u062f (\u06f1\u06f9\u06f1\u06f8 \u062a\u0627 \u06f1\u06f9\u06f8\u06f1)" },
            { "isk", "\u06a9\u0631\u0648\u0646\u0627\u06cc \u0627\u06cc\u0633\u0644\u0646\u062f" },
            { "itl", "\u0644\u06cc\u0631\u0647\u0654 \u0627\u06cc\u062a\u0627\u0644\u06cc\u0627" },
            { "jmd", "\u062f\u0644\u0627\u0631 \u062c\u0627\u0645\u0627\u0626\u06cc\u06a9\u0627" },
            { "jod", "\u062f\u06cc\u0646\u0627\u0631 \u0627\u0631\u062f\u0646" },
            { "jpy", "\u06cc\u0646 \u0698\u0627\u067e\u0646" },
            { "kes", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u06a9\u0646\u06cc\u0627" },
            { "kgs", "\u0633\u0648\u0645 \u0642\u0631\u0642\u06cc\u0632\u0633\u062a\u0627\u0646" },
            { "khr", "\u0631\u06cc\u200c\u06cc\u0644 \u06a9\u0627\u0645\u0628\u0648\u062c" },
            { "kmf", "\u0641\u0631\u0627\u0646\u06a9 \u06a9\u0648\u0645\u0648\u0631\u0648" },
            { "kpw", "\u0648\u0648\u0646 \u06a9\u0631\u0647\u0654 \u0634\u0645\u0627\u0644\u06cc" },
            { "kro", "\u0648\u0648\u0646 \u06a9\u0631\u0647\u0654 \u062c\u0646\u0648\u0628\u06cc (\u06f1\u06f9\u06f4\u06f5 \u062a\u0627 \u06f1\u06f9\u06f5\u06f3)" },
            { "krw", "\u0648\u0648\u0646 \u06a9\u0631\u0647\u0654 \u062c\u0646\u0648\u0628\u06cc" },
            { "kwd", "\u062f\u06cc\u0646\u0627\u0631 \u06a9\u0648\u06cc\u062a" },
            { "kyd", "\u062f\u0644\u0627\u0631 \u062c\u0632\u0627\u06cc\u0631 \u06a9\u0650\u06cc\u0645\u0646" },
            { "kzt", "\u062a\u0646\u06af\u0647\u0654 \u0642\u0632\u0627\u0642\u0633\u062a\u0627\u0646" },
            { "lak", "\u06a9\u06cc\u067e \u0644\u0627\u0626\u0648\u0633" },
            { "lbp", "\u0644\u06cc\u0631\u0647\u0654 \u0644\u0628\u0646\u0627\u0646" },
            { "lkr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0633\u0631\u06cc\u200c\u0644\u0627\u0646\u06a9\u0627" },
            { "lrd", "\u062f\u0644\u0627\u0631 \u0644\u06cc\u0628\u0631\u06cc\u0627" },
            { "lsl", "\u0644\u0648\u062a\u06cc \u0644\u0633\u0648\u062a\u0648" },
            { "ltl", "\u0644\u06cc\u062a\u0627\u0633 \u0644\u06cc\u062a\u0648\u0627\u0646\u06cc" },
            { "ltt", "\u062a\u0627\u0644\u0648\u0646\u0627\u0633 \u0644\u06cc\u062a\u0648\u0627\u0646\u06cc" },
            { "luf", "\u0641\u0631\u0627\u0646\u06a9 \u0644\u0648\u06a9\u0632\u0627\u0645\u0628\u0648\u0631\u06af" },
            { "lul", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0627\u0644\u06cc \u0644\u0648\u06af\u0632\u0627\u0645\u0628\u0648\u0631\u06af" },
            { "lvl", "\u0644\u0627\u062a\u0633 \u0644\u062a\u0648\u0646\u06cc" },
            { "lvr", "\u0631\u0648\u0628\u0644 \u0644\u062a\u0648\u0646\u06cc" },
            { "lyd", "\u062f\u06cc\u0646\u0627\u0631 \u0644\u06cc\u0628\u06cc" },
            { "mad", "\u062f\u0631\u0647\u0645 \u0645\u0631\u0627\u06a9\u0634" },
            { "maf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0631\u0627\u06a9\u0634" },
            { "mcf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0648\u0646\u0627\u06a9\u0648" },
            { "mdl", "\u0644\u0626\u0648\u06cc \u0645\u0648\u0644\u062f\u0627\u0648\u06cc" },
            { "mga", "\u0622\u0631\u06cc\u0627\u0631\u06cc \u0645\u0627\u0644\u0627\u06af\u0627\u0633\u06cc" },
            { "mgf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0627\u062f\u0627\u06af\u0627\u0633\u06a9\u0627\u0631" },
            { "mkd", "\u062f\u06cc\u0646\u0627\u0631 \u0645\u0642\u062f\u0648\u0646\u06cc\u0647" },
            { "mkn", "\u062f\u06cc\u0646\u0627\u0631 \u0645\u0642\u062f\u0648\u0646\u06cc\u0647 (\u06f1\u06f9\u06f9\u06f2 \u062a\u0627 \u06f1\u06f9\u06f9\u06f3)" },
            { "mlf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0627\u0644\u06cc" },
            { "mmk", "\u06a9\u06cc\u0627\u062a \u0645\u06cc\u0627\u0646\u0645\u0627\u0631" },
            { "mnt", "\u062a\u0648\u06af\u0631\u06cc\u06a9 \u0645\u063a\u0648\u0644\u0633\u062a\u0627\u0646" },
            { "mop", "\u067e\u0627\u062a\u0627\u06a9\u0627\u06cc \u0645\u0627\u06a9\u0627\u0626\u0648" },
            { "mro", "\u0627\u0648\u06af\u0648\u0626\u06cc\u0627\u06cc \u0645\u0648\u0631\u06cc\u062a\u0627\u0646\u06cc (\u06f1\u06f9\u06f7\u06f3 \u062a\u0627 \u06f2\u06f0\u06f1\u06f7)" },
            { "mru", "\u0627\u0648\u06af\u0648\u0626\u06cc\u0627\u06cc \u0645\u0648\u0631\u06cc\u062a\u0627\u0646\u06cc" },
            { "mtl", "\u0644\u06cc\u0631\u0647\u0654 \u0645\u0627\u0644\u062a" },
            { "mtp", "\u067e\u0648\u0646\u062f \u0645\u0627\u0644\u062a" },
            { "mur", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0645\u0648\u0631\u06cc\u0633" },
            { "mvp", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0645\u0627\u0644\u062f\u06cc\u0648 (\u06f1\u06f9\u06f4\u06f7 \u062a\u0627 \u06f1\u06f9\u06f8\u06f1)" },
            { "mvr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0645\u0627\u0644\u062f\u06cc\u0648" },
            { "mwk", "\u06a9\u0648\u0627\u0686\u0627\u06cc \u0645\u0627\u0644\u0627\u0648\u06cc" },
            { "mxn", "\u067e\u0632\u0648\u06cc \u0645\u06a9\u0632\u06cc\u06a9" },
            { "mxp", "\u067e\u0632\u0648\u06cc \u0646\u0642\u0631\u0647\u0654 \u0645\u06a9\u0632\u06cc\u06a9 (\u06f1\u06f8\u06f6\u06f1 \u062a\u0627 \u06f1\u06f9\u06f9\u06f2)" },
            { "myr", "\u0631\u06cc\u0646\u06af\u06cc\u062a \u0645\u0627\u0644\u0632\u06cc" },
            { "mze", "\u0627\u0633\u06a9\u0648\u062f\u0648\u06cc \u0645\u0648\u0632\u0627\u0645\u0628\u06cc\u06a9" },
            { "mzn", "\u0645\u062a\u06cc\u06a9\u0627\u0644 \u0645\u0648\u0632\u0627\u0645\u0628\u06cc\u06a9" },
            { "nad", "\u062f\u0644\u0627\u0631 \u0646\u0627\u0645\u06cc\u0628\u06cc\u0627" },
            { "ngn", "\u0646\u0627\u06cc\u0631\u0627\u06cc \u0646\u06cc\u062c\u0631\u06cc\u0647" },
            { "nio", "\u06a9\u0648\u0631\u062f\u0648\u0628\u0627\u06cc \u0646\u06cc\u06a9\u0627\u0631\u0627\u06af\u0648\u0626\u0647" },
            { "nlg", "\u06af\u06cc\u0644\u062f\u0631 \u0647\u0644\u0646\u062f" },
            { "nok", "\u06a9\u0631\u0648\u0646 \u0646\u0631\u0648\u0698" },
            { "npr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0646\u067e\u0627\u0644" },
            { "nzd", "\u062f\u0644\u0627\u0631 \u0632\u0644\u0627\u0646\u062f \u0646\u0648" },
            { "omr", "\u0631\u06cc\u0627\u0644 \u0639\u0645\u0627\u0646" },
            { "pab", "\u0628\u0627\u0644\u0628\u0648\u0627\u06cc \u067e\u0627\u0646\u0627\u0645\u0627" },
            { "pei", "\u0627\u06cc\u0646\u062a\u06cc \u067e\u0631\u0648" },
            { "pen", "\u0633\u0648\u0644 \u067e\u0631\u0648" },
            { "pes", "\u0633\u0648\u0644 \u067e\u0631\u0648 (\u06f1\u06f8\u06f6\u06f3 \u062a\u0627 \u06f1\u06f9\u06f6\u06f5)" },
            { "pgk", "\u06a9\u06cc\u0646\u0627\u06cc \u067e\u0627\u067e\u0648\u0627 \u06af\u06cc\u0646\u0647\u0654 \u0646\u0648" },
            { "php", "\u067e\u0632\u0648\u06cc \u0641\u06cc\u0644\u06cc\u067e\u06cc\u0646" },
            { "pkr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u067e\u0627\u06a9\u0633\u062a\u0627\u0646" },
            { "pln", "\u0632\u0648\u0627\u062a\u06cc \u0644\u0647\u0633\u062a\u0627\u0646" },
            { "pte", "\u0627\u0633\u06a9\u0648\u062f\u0648\u06cc \u067e\u0631\u062a\u063a\u0627\u0644" },
            { "pyg", "\u06af\u0648\u0627\u0631\u0627\u0646\u06cc \u067e\u0627\u0631\u0627\u06af\u0648\u0626\u0647" },
            { "qar", "\u0631\u06cc\u0627\u0644 \u0642\u0637\u0631" },
            { "rhd", "\u062f\u0644\u0627\u0631 \u0631\u0648\u062f\u0632\u06cc\u0627" },
            { "ron", "\u0644\u0626\u0648\u06cc \u0631\u0648\u0645\u0627\u0646\u06cc" },
            { "rsd", "\u062f\u06cc\u0646\u0627\u0631 \u0635\u0631\u0628\u0633\u062a\u0627\u0646" },
            { "rub", "\u0631\u0648\u0628\u0644 \u0631\u0648\u0633\u06cc\u0647" },
            { "rur", "\u0631\u0648\u0628\u0644 \u0631\u0648\u0633\u06cc\u0647 (\u06f1\u06f9\u06f9\u06f1 \u062a\u0627 \u06f1\u06f9\u06f9\u06f8)" },
            { "rwf", "\u0641\u0631\u0627\u0646\u06a9 \u0631\u0648\u0627\u0646\u062f\u0627" },
            { "sar", "\u0631\u06cc\u0627\u0644 \u0633\u0639\u0648\u062f\u06cc" },
            { "sbd", "\u062f\u0644\u0627\u0631 \u062c\u0632\u0627\u06cc\u0631 \u0633\u0644\u06cc\u0645\u0627\u0646" },
            { "scr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0633\u06cc\u0634\u0644" },
            { "sdd", "\u062f\u06cc\u0646\u0627\u0631 \u0633\u0648\u062f\u0627\u0646 (\u06f1\u06f9\u06f9\u06f2 \u062a\u0627 \u06f2\u06f0\u06f0\u06f7)" },
            { "sdg", "\u067e\u0648\u0646\u062f \u0633\u0648\u062f\u0627\u0646" },
            { "sek", "\u06a9\u0631\u0648\u0646 \u0633\u0648\u0626\u062f" },
            { "sgd", "\u062f\u0644\u0627\u0631 \u0633\u0646\u06af\u0627\u067e\u0648\u0631" },
            { "shp", "\u067e\u0648\u0646\u062f \u0633\u0646\u062a \u0647\u0644\u0646" },
            { "sll", "\u0644\u0626\u0648\u0646 \u0633\u06cc\u0631\u0627\u0644\u0626\u0648\u0646" },
            { "sos", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0633\u0648\u0645\u0627\u0644\u06cc" },
            { "srd", "\u062f\u0644\u0627\u0631 \u0633\u0648\u0631\u06cc\u0646\u0627\u0645" },
            { "srg", "\u06af\u06cc\u0644\u062f\u0631 \u0633\u0648\u0631\u06cc\u0646\u0627\u0645" },
            { "ssp", "\u067e\u0648\u0646\u062f \u0633\u0648\u062f\u0627\u0646 \u062c\u0646\u0648\u0628\u06cc" },
            { "std", "\u062f\u0648\u0628\u0631\u0627\u06cc \u0633\u0627\u0626\u0648\u062a\u0648\u0645\u0647 \u0648 \u067e\u0631\u0646\u0633\u06cc\u067e (\u06f1\u06f9\u06f7\u06f7 \u062a\u0627 \u06f2\u06f0\u06f1\u06f7)" },
            { "stn", "\u062f\u0648\u0628\u0631\u0627\u06cc \u0633\u0627\u0626\u0648\u062a\u0648\u0645\u0647 \u0648 \u067e\u0631\u0646\u0633\u06cc\u067e" },
            { "sur", "\u0631\u0648\u0628\u0644 \u0634\u0648\u0631\u0648\u06cc" },
            { "syp", "\u0644\u06cc\u0631\u0647\u0654 \u0633\u0648\u0631\u06cc\u0647" },
            { "szl", "\u0644\u06cc\u0644\u0627\u0646\u06af\u0646\u06cc \u0633\u0648\u0627\u0632\u06cc\u0644\u0646\u062f" },
            { "thb", "\u0628\u0627\u062a \u062a\u0627\u06cc\u0644\u0646\u062f" },
            { "tjr", "\u0631\u0648\u0628\u0644 \u062a\u0627\u062c\u06cc\u06a9\u0633\u062a\u0627\u0646" },
            { "tjs", "\u0633\u0627\u0645\u0627\u0646\u06cc \u062a\u0627\u062c\u06cc\u06a9\u0633\u062a\u0627\u0646" },
            { "tmm", "\u0645\u0646\u0627\u062a \u062a\u0631\u06a9\u0645\u0646\u0633\u062a\u0627\u0646 (\u06f1\u06f9\u06f9\u06f3 \u062a\u0627 \u06f2\u06f0\u06f0\u06f9)" },
            { "tmt", "\u0645\u0646\u0627\u062a \u062a\u0631\u06a9\u0645\u0646\u0633\u062a\u0627\u0646" },
            { "tnd", "\u062f\u06cc\u0646\u0627\u0631 \u062a\u0648\u0646\u0633" },
            { "top", "\u067e\u0627\u0622\u0646\u06af\u0627\u06cc \u062a\u0648\u0646\u06af\u0627" },
            { "tpe", "\u0627\u0633\u06a9\u0648\u062f\u0648\u06cc \u062a\u06cc\u0645\u0648\u0631" },
            { "trl", "\u0644\u06cc\u0631\u0647\u0654 \u062a\u0631\u06a9\u06cc\u0647 (\u06f1\u06f9\u06f2\u06f2 \u062a\u0627 \u06f2\u06f0\u06f0\u06f5)" },
            { "try", "\u0644\u06cc\u0631\u0647\u0654 \u062a\u0631\u06a9\u06cc\u0647" },
            { "ttd", "\u062f\u0644\u0627\u0631 \u062a\u0631\u06cc\u0646\u06cc\u062f\u0627\u062f \u0648 \u062a\u0648\u0628\u0627\u06af\u0648" },
            { "twd", "\u062f\u0644\u0627\u0631 \u062c\u062f\u06cc\u062f \u062a\u0627\u06cc\u0648\u0627\u0646" },
            { "tzs", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u062a\u0627\u0646\u0632\u0627\u0646\u06cc\u0627" },
            { "uah", "\u0647\u0631\u06cc\u0648\u0646\u06cc\u0627\u06cc \u0627\u0648\u06a9\u0631\u0627\u06cc\u0646" },
            { "ugs", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0627\u0648\u06af\u0627\u0646\u062f\u0627 (\u06f1\u06f9\u06f6\u06f6 \u062a\u0627 \u06f1\u06f9\u06f8\u06f7)" },
            { "ugx", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0627\u0648\u06af\u0627\u0646\u062f\u0627" },
            { "usd", "\u062f\u0644\u0627\u0631 \u0622\u0645\u0631\u06cc\u06a9\u0627" },
            { "usn", "\u062f\u0644\u0627\u0631 \u0627\u0645\u0631\u06cc\u06a9\u0627 (\u0631\u0648\u0632 \u0628\u0639\u062f)" },
            { "uss", "\u062f\u0644\u0627\u0631 \u0627\u0645\u0631\u06cc\u06a9\u0627 (\u0647\u0645\u0627\u0646 \u0631\u0648\u0632)" },
            { "uyp", "\u067e\u0632\u0648\u06cc \u0627\u0648\u0631\u0648\u06af\u0648\u0626\u0647 (\u06f1\u06f9\u06f7\u06f5 \u062a\u0627 \u06f1\u06f9\u06f9\u06f3)" },
            { "uyu", "\u067e\u0632\u0648\u06cc \u0627\u0648\u0631\u0648\u06af\u0648\u0626\u0647" },
            { "uzs", "\u0633\u0648\u0645 \u0627\u0632\u0628\u06a9\u0633\u062a\u0627\u0646" },
            { "veb", "\u0628\u0648\u0644\u06cc\u0648\u0627\u0631 \u0648\u0646\u0632\u0648\u0626\u0644\u0627 (\u06f1\u06f8\u06f7\u06f1 \u062a\u0627 \u06f2\u06f0\u06f0\u06f8)" },
            { "vef", "\u0628\u0648\u0644\u06cc\u0648\u0627\u0631 \u0648\u0646\u0632\u0648\u0626\u0644\u0627 (\u06f2\u06f0\u06f0\u06f8 \u062a\u0627 \u06f2\u06f0\u06f1\u06f8)" },
            { "ves", "\u0628\u0648\u0644\u06cc\u0648\u0627\u0631 \u0648\u0646\u0632\u0648\u0626\u0644\u0627" },
            { "vnd", "\u062f\u0627\u0646\u06af \u0648\u06cc\u062a\u0646\u0627\u0645" },
            { "vuv", "\u0648\u0627\u062a\u0648\u06cc \u0648\u0627\u0646\u0648\u0648\u0627\u062a\u0648" },
            { "wst", "\u062a\u0627\u0644\u0627\u06cc \u0633\u0627\u0645\u0648\u0627" },
            { "xaf", "\u0641\u0631\u0627\u0646\u06a9 CFA \u0645\u0631\u06a9\u0632 \u0627\u0641\u0631\u06cc\u0642\u0627" },
            { "xag", "\u0646\u0642\u0631\u0647" },
            { "xau", "\u0637\u0644\u0627" },
            { "xcd", "\u062f\u0644\u0627\u0631 \u0634\u0631\u0642 \u06a9\u0627\u0631\u0627\u0626\u06cc\u0628" },
            { "xfo", "\u0641\u0631\u0627\u0646\u06a9 \u0637\u0644\u0627\u06cc \u0641\u0631\u0627\u0646\u0633\u0647" },
            { "xof", "\u0641\u0631\u0627\u0646\u06a9 CFA \u063a\u0631\u0628 \u0627\u0641\u0631\u06cc\u0642\u0627" },
            { "xpd", "\u067e\u0627\u0644\u0627\u062f\u06cc\u0645" },
            { "xpf", "\u0641\u0631\u0627\u0646\u06a9 \u0627\u0642\u06cc\u0627\u0646\u0648\u0633\u06cc\u0647" },
            { "xpt", "\u067e\u0644\u0627\u062a\u06cc\u0646" },
            { "xts", "\u0627\u0631\u0632 \u0622\u0632\u0645\u0627\u06cc\u0634\u06cc" },
            { "xxx", "\u0627\u0631\u0632 \u0646\u0627\u0645\u0634\u062e\u0635" },
            { "ydd", "\u062f\u06cc\u0646\u0627\u0631 \u06cc\u0645\u0646" },
            { "yer", "\u0631\u06cc\u0627\u0644 \u06cc\u0645\u0646" },
            { "zar", "\u0631\u0627\u0646\u062f \u0627\u0641\u0631\u06cc\u0642\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc" },
            { "zmk", "\u06a9\u0648\u0627\u0686\u0627\u06cc \u0632\u0627\u0645\u0628\u06cc\u0627 (\u06f1\u06f9\u06f6\u06f8 \u062a\u0627 \u06f2\u06f0\u06f1\u06f2)" },
            { "zmw", "\u06a9\u0648\u0627\u0686\u0627\u06cc \u0632\u0627\u0645\u0628\u06cc\u0627" },
            { "zwd", "\u062f\u0644\u0627\u0631 \u0632\u06cc\u0645\u0628\u0627\u0628\u0648\u0647 (\u06f1\u06f9\u06f8\u06f0 \u062a\u0627 \u06f2\u06f0\u06f0\u06f8)" },
            { "zwl", "\u062f\u0644\u0627\u0631 \u0632\u06cc\u0645\u0628\u0627\u0628\u0648\u0647 (\u06f2\u06f0\u06f0\u06f9)" },
            { "zwr", "\u062f\u0644\u0627\u0631 \u0632\u06cc\u0645\u0628\u0627\u0628\u0648\u0647 (\u06f2\u06f0\u06f0\u06f8)" },
        };
        return data;
    }
}
